@@ -28,7 +28,7 @@ from .validators import ModelExistingValidator, ModelLoadedValidator
 from .validators import InputValidator, ArgumentValidator
 from . import exceptions
 
-from transformers import BertTokenizer, BertForSequenceClassification, BertConfig, RobertaForSequenceClassification, RobertaTokenizer
+from transformers import BertTokenizer, BertForSequenceClassification, BertConfig, RobertaForSequenceClassification, RobertaTokenizer, AutoTokenizer
 from transformers import AdamW, get_linear_schedule_with_warmup
 
 from torch.utils.data import DataLoader, TensorDataset
@@ -81,6 +81,7 @@ class BertTagger:
 
         self.optimizer = None
         self.scheduler = None
+        self.tokenizer = None
 
 
     def _make_dir(self, _dir: str):
@@ -313,7 +314,14 @@ class BertTagger:
             if not BertTagger.is_roberta_model(bert_model):
                 tokenizer = BertTokenizer.from_pretrained(bert_model, **model_kwargs)
             else:
-                tokenizer = RobertaTokenizer.from_pretrained(bert_model, **model_kwargs)
+                try:
+                    if logger: logger.info(f"Trying to use RobertaTokenizer...")
+                    tokenizer = RobertaTokenizer.from_pretrained(bert_model, **model_kwargs)
+                except Exception as e:
+                    if logger: logger.info(f"Failed loading RobertaTokenizer, trying to use AutoTokenizer...")
+                    model_kwargs.update({"use_fast": False})
+                    tokenizer = AutoTokenizer.from_pretrained(bert_model, **model_kwargs)
+
             tokenizer.save_pretrained(tokenizer_dir)
             if logger: logger.info(f"Download finished! Pretrained tokenizer saved into {tokenizer_dir}.")
         else:
@@ -539,8 +547,13 @@ class BertTagger:
             self._print("Using regular BERT tokenizer...")
             tokenizer = BertTokenizer.from_pretrained(model_to_load, **model_kwargs)
         else:
-            self._print("Using RobertaTokenizer...")
-            tokenizer = RobertaTokenizer.from_pretrained(model_to_load, **model_kwargs)
+            try:
+                self._print("Using RobertaTokenizer...")
+                tokenizer = RobertaTokenizer.from_pretrained(model_to_load, **model_kwargs)
+            except Exception as e:
+                self._print("Failed loading RobertaTokenizer, trying to use AutoTokenizer...")
+                model_kwargs.update({"use_fast": False})
+                tokenizer = AutoTokenizer.from_pretrained(model_to_load, **model_kwargs)
 
 
         if self.save_pretrained and not model_downloaded:
@@ -562,7 +575,8 @@ class BertTagger:
             labels - Labels as torch.tensors instance.
 
         """
-        tokenizer = self.load_tokenizer()
+        if not self.tokenizer:
+            self.tokenizer = self.load_tokenizer()
 
         input_ids = []
         attention_masks = []
@@ -576,7 +590,7 @@ class BertTagger:
             #   (4) Map tokens to their IDs.
             #   (5) Pad or truncate the sentence to `max_length`
             #   (6) Create attention masks for [PAD] tokens.
-            encoded_dict = tokenizer.encode_plus(
+            encoded_dict = self.tokenizer.encode_plus(
                                 sentence,
                                 add_special_tokens = self.config.add_special_tokens,
                                 max_length = self.config.max_length,
@@ -776,6 +790,8 @@ class BertTagger:
         # Make sure not to use old pos label
         if not "pos_label" in kwargs:
             self.config.pos_label = ""
+        # Update tokenizer as it might have been changed
+        self.tokenizer = self.load_tokenizer()
         return True
 
 
